ClockId

Enum ClockId 

pub enum ClockId {
    Realtime = 0,
    RealtimeAlarm = 8,
    Monotonic = 1,
    Boottime = 7,
    BoottimeAlarm = 9,
}

Variants



Realtime = 0

Available clocks:

A settable system-wide real-time clock.



RealtimeAlarm = 8

This clock is like CLOCK_REALTIME, but will wake the system if it is suspended. The caller must have the CAP_WAKE_ALARM capability in order to set a timer against this clock.



Monotonic = 1

A nonsettable monotonically increasing clock that measures time from some unspecified point in the past that does not change after system startup.



Boottime = 7

Like CLOCK_MONOTONIC, this is a monotonically increasing clock. However, whereas the CLOCK_MONOTONIC clock does not measure the time while a system is suspended, the CLOCK_BOOTTIME clock does include the time during which the system is suspended. This is useful for applications that need to be suspend-aware. CLOCK_REALTIME is not suitable for such applications, since that clock is affected by discon‐ tinuous changes to the system clock.



BoottimeAlarm = 9

This clock is like CLOCK_BOOTTIME, but will wake the system if it is suspended. The caller must have the CAP_WAKE_ALARM capability in order to set a timer against this clock.